is_model_compatible_with_provider

Function is_model_compatible_with_provider 

pub fn is_model_compatible_with_provider(provider: &str, model_id: &str) -> bool
Returns true if the model_id is compatible with provider.

Compatibility is determined via infer_provider_from_model_id. If a provider cannot be inferred for the model id, this returns true to avoid blocking legitimate custom/unknown model ids.

Providers with user-defined model ids (ollama) are always treated as compatible.